@@ -9,7 +9,12 @@
   n <- length(x = y)
 
   # obtain model matrix
-  X1 <- stats::model.matrix(object = ~. , data = as.data.frame(x = X))
+  if (ncol(X) > 0L) {
+    X1 <- stats::model.matrix(~. , as.data.frame(X))
+  } else {
+    X1 <- matrix(1.0, nrow(X), ncol = 1L)
+  }
+  
   
   # logistic regression
   glmfit <- stats::glm(y ~ X1-1, family = "binomial")
