@@ -8,8 +8,12 @@
 
   n <- length(x = y)
   
-  X1 <- stats::model.matrix(~. , as.data.frame(X))
-
+  if (ncol(X) > 0L) {
+    X1 <- stats::model.matrix(~. , as.data.frame(X))
+  } else {
+    X1 <- matrix(1.0, nrow(X), ncol = 1L)
+  }
+  
   mod <- stats::lm(y ~ X1 - 1)
   res <- residuals(object = mod)
   s2 <- sum(res^2)
